@@ -1,4 +1,5 @@
 import inspect
+import os
 import re
 from string import Template
 
@@ -27,9 +28,13 @@ def github_group(group_name):
                         value = getattr(value, attr, None)
                 attribute_template = object_attribute.replace(".", "_")
                 template_dict[attribute_template] = value
-                inner_group_name = re.sub(rf"\$\({attribute}\)", f"${attribute_template}", inner_group_name)
+                inner_group_name = re.sub(
+                    rf"\$\({attribute}\)", f"${attribute_template}", inner_group_name
+                )
 
-            print(f"::group::{Template(inner_group_name).safe_substitute(**template_dict)}")
+            print(
+                f"::group::{Template(inner_group_name).safe_substitute(**template_dict)}"
+            )
             resp = f(*args, **kwargs)
             print("::endgroup::")
             return resp
@@ -37,3 +42,13 @@ def github_group(group_name):
         return inner_wrapper
 
     return wrapper
+
+
+def summary(text, overwrite=False):
+    summary_file_path = os.getenv("GITHUB_STEP_SUMMARY")
+
+    # Open the file in append mode
+    mode = "w" if overwrite else "a"
+    with open(summary_file_path, mode) as f:
+        # Write to the file
+        f.write(f"{text}\n")
